# coding: utf-8

from django.conf import settings as s
from django.core.exceptions import ImproperlyConfigured
from django.utils.translation import ugettext_lazy as _
from django_ulogin.exceptions import SchemeNotFound


ALLOWED_PROVIDERS = (
    ('vkontakte',       _('V Kontakte')),
    ('odnoklassniki',   _('Odnoklassniki')),
    ('mailru',          _('Mail.Ru')),
    ('yandex',          _('Yandex')),
    ('lastfm',          _('Last.FM')),
    ('linkedin',        _('LinkedIn')),
    ('google',          _('Google')),
    ('soundcloud',      _('SoundCloud')),
    ('steam',           _('Steam')),
    ('liveid',          _('Windows Live ID')),
    ('vimeo',           _('Vimeo')),
    ('openid',          _('OpenID')),
    ('webmoney',        _('WebMoney')),
    ('flickr',          _('Flickr')),
    ('youtube',         _('YouTube')),
    ('livejournal',     _('LiveJournal')),
    ('twitter',         _('Twitter')),
    ('facebook',        _('Facebook')),
)

ALLOWED_FIELDS = (
    ('first_name',  _('First name')),
    ('last_name',   _('Last name')),
    ('email',       _('E-mail')),
    ('nickname',    _('Nickname')),
    ('bdate',       _('Birthday')),
    ('sex',         _('Sex')),
    ('photo',       _('Photo')),
    ('photo_big',   _('Big photo')),
    ('city',        _('City')),
    ('country',     _('Country')),
    ('phone',       _('Phone')),
)

SEX_CHOICES = (
    (1, _('female')),
    (2, _('male')),
)


# URL of widget
WIDGET_URL = getattr(s, 'ULOGIN_WIDGET_URL', '//ulogin.ru/js/ulogin.js')

# URL to get token
TOKEN_URL = getattr(s, 'ULOGIN_TOKEN_URL', 'https://ulogin.ru/token.php')

REDIRECT_URL = getattr(s, 'ULOGIN_REDIRECT_URL', None)

LOAD_SCRIPT_AT_ONCE = getattr(s, 'ULOGIN_LOAD_SCRIPT_AT_ONCE', False)

##
## Default settings
##
# Required fields
FIELDS = getattr(s, 'ULOGIN_FIELDS', ['email'])

# Optional fields
OPTIONAL = getattr(s, 'ULOGIN_OPTIONAL', [])

# Display type. The variants 'panel', 'small' and 'button' are available
DISPLAY = getattr(s, 'ULOGIN_DISPLAY', 'small')

# Featured providers
PROVIDERS = getattr(s, 'ULOGIN_PROVIDERS',
                'vkontakte,facebook,twitter,google,livejournal'.split(','))

# Providers in dropdown list
HIDDEN = getattr(s, 'ULOGIN_HIDDEN',
                 'yandex,odnoklassniki,mailru,openid'.split(','))

# Callback function
CALLBACK = getattr(s, 'ULOGIN_CALLBACK', None)

DEFAULT_SCHEME = {
    'FIELDS': FIELDS,
    'OPTIONAL': OPTIONAL,
    'DISPLAY': DISPLAY,
    'PROVIDERS': PROVIDERS,
    'HIDDEN': HIDDEN,
    'CALLBACK': CALLBACK,
}

SCHEMES = getattr(s, 'ULOGIN_SCHEMES', {'default': DEFAULT_SCHEME})


def get_scheme(name):
    try:
        scheme = SCHEMES[name]
    except KeyError:
        raise SchemeNotFound(
            "Scheme with name {name} not found".format(name=name))
    return {
        'FIELDS': scheme.get('FIELDS',    FIELDS),
        'OPTIONAL': scheme.get('OPTIONAL',  OPTIONAL),
        'DISPLAY': scheme.get('DISPLAY',   DISPLAY),
        'PROVIDERS': scheme.get('PROVIDERS', PROVIDERS),
        'HIDDEN': scheme.get('HIDDEN',    HIDDEN),
        'CALLBACK': scheme.get('CALLBACK',  CALLBACK),
    }



# -*- coding: utf-8 -*-

from django.dispatch import Signal

assign = Signal(providing_args=['request', 'user',
                                'ulogin_user', 'ulogin_data',
                                'registered'])



# coding: utf-8

from django.conf.urls import url
from django_ulogin.views import PostBackView, CrossDomainView, \
    IdentityListView, IdentityDeleteView

urlpatterns = [
    url('^identities/$',
        view=IdentityListView.as_view(),
        name='ulogin_identities_list'),
    url('^identities/(?P<pk>\d+)/delete/$',
        view=IdentityDeleteView.as_view(),
        name='ulogin_identities_delete'),
    url('^postback/$',
        view=PostBackView.as_view(),
        name='ulogin_postback'),
    url('^ulogin_xd.html$',
        view=CrossDomainView.as_view(),
        name='ulogin_xd'),
]



# coding: utf-8

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from django_ulogin import settings as s


class ULoginUser(models.Model):
    user = models.ForeignKey(User,
        related_name='ulogin_users',
        verbose_name=_('user'))
    network = models.CharField(_('network'),
        db_index=True,
        max_length=255,
        choices=s.ALLOWED_PROVIDERS)
    identity = models.URLField(_('identity'),
        db_index=True,
        max_length=255)
    uid = models.CharField(_('uid'),
        db_index=True,
        max_length=255)
    date_created = models.DateTimeField(_('date created'),
        editable=False,
        auto_now=True)

    def __unicode__(self):
        return unicode(self.user)

    @models.permalink
    def get_delete_url(self):
        return 'ulogin_identities_delete', [self.pk]

    class Meta:
        verbose_name = _('ulogin user')
        verbose_name_plural = _('ulogin users')
        unique_together = [('network', 'uid')]



#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages
import os

version = __import__('django_ulogin').get_version()
readme = os.path.join(os.path.dirname(__file__), 'README.rst')

CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Framework :: Django'
]

setup(
    name='django-ulogin',
    author='Mikhail Porokhovnichenko <marazmiki@gmail.com>',
    version=version,
    author_email='marazmiki@gmail.com',
    url='http://pypi.python.org/pypi/django-ulogin',
    download_url='http://bitbucket.org/marazmiki/django-ulogin/get/tip.zip',
    description='User social authentication with ulogin.ru service',
    long_description=open(readme).read(),
    license='MIT license',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    install_requires=[
        'Django>=1.3.1',
        'requests>=0.7.4',
        'mock>=0.8.0',
    ],
    packages=find_packages(exclude=['test_project', 'test_project.*']),
    include_package_data=True,
    zip_safe=False)
